@@ -18,6 +18,7 @@
 #define setaction(b,c)  NULL, 1, NULL, NULL
 #define toolaction(b,c) NULL, NULL
 #define noaction        NULL, 0, NULL, NULL
+#define offset(a)	0
 
 #else                   /* real definitions. . .*/
 
@@ -27,6 +28,7 @@
 #define setaction(b,c)	NULL, 1, (XtCallbackProc)b, c
 #define toolaction(b,c) (XtCallbackProc)b, c
 #define noaction	NULL, 0, (XtCallbackProc)DoNothing, NULL
+#define offset(a)	XtOffset(XCWindowDataPtr, a)
 
 #endif
 
@@ -176,7 +178,7 @@ menustruct Stipples[] = {
 };
 
 menustruct TextMenu[] = {
-	{"Text Size", action(gettsize, &areawin->textscale)},
+	{"Text Size", action(gettsize, NULL)},
 	{"Font", submenu(Fonts)},
 	{"Style", submenu(FontStyles)},
 	{"Encoding", submenu(FontEncodings)},
@@ -197,8 +199,8 @@ menustruct PolyMenu[] = {
 	{" ", noaction},
 	{"Object size", action(getosize, NULL)},
 	{"Parameters", submenu(Parameterize)},
-	{"Center Object", setaction(toggle, &areawin->center)},
-	{"Manhattan Draw", action(toggle, &areawin->manhatn)},
+	{"Center Object", setaction(toggle, offset(center))},
+	{"Manhattan Draw", action(toggle, offset(manhatn))},
 	{"Polygon Edit", submenu(BoxEditStyles)},
 };
 
@@ -236,14 +238,14 @@ menustruct LineMenu[] = {
 };
 
 menustruct GridMenu[] = {
-	{"Grid", setaction(toggle, &areawin->gridon)},
-	{"Axes", setaction(toggle, &areawin->axeson)},
+	{"Grid", setaction(toggle, offset(gridon))},
+	{"Axes", setaction(toggle, offset(axeson))},
 	{"Grid spacing", action(getgridspace, NULL)},
 	{"Grid type/display", submenu(GridStyles)},
 };
 
 menustruct SnapMenu[] = {
-	{"Snap-to", setaction(toggle, &areawin->snapto)},
+	{"Snap-to", setaction(toggle, offset(snapto))},
         {"Snap spacing", action(getsnapspace, NULL)},
 };
 
@@ -306,10 +308,10 @@ menustruct FileMenu[] = {
 };
 
 menustruct OptionMenu[] = {
-	{"Alt Colors", action(inversecolor, &areawin->invert)},
-	{"Show Bounding box", action(toggle, &areawin->bboxon)},
-	{"Edit in place", setaction(toggle, &areawin->editinplace)},
-	{"Show Pin Positions", action(toggle, &areawin->pinpointon)},
+	{"Alt Colors", action(inversecolor, offset(invert))},
+	{"Show Bounding box", action(toggle, offset(bboxon))},
+	{"Edit in place", setaction(toggle, offset(editinplace))},
+	{"Show Pin Positions", action(toggle, offset(pinpointon))},
 	{"Enable XSchema", action(doxschema, Number(1))},
 #ifdef HAVE_XPM
 	{"Disable Toolbar", action(dotoolbar, NULL)},
@@ -424,5 +426,6 @@ short toolbuttons = sizeof(ToolBar) / sizeof(toolbarstruct);
 #undef setaction
 #undef toolaction
 #undef noaction
+#undef offset
 
 /*-------------------------------------------------------------------------*/
